@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 ###
-### $Release: 0.12.0 $
+### $Release: 0.12.1 $
 ### $Copyright: copyright(c) 2010-2014 kuwata-lab.com all rights reserved $
 ### $License: MIT License $
 ###
@@ -573,7 +573,7 @@ attr('val'): 'aaa\nbbb\nccc\n' == 'aaa\nbbbb\nccc\n' : failed.
 
 
     def test_should(self):
-        ok ("foobar").should.startswith("foob")
+        ok ("foobar").should.startswith("foob").endswith("bar")
         @be_fail("'foobar'.startswith('aaa') : failed.")
         def fn(): ok ("foobar").should.startswith("aaa")
         #
